# uom-project

Repository containing code and and other materials for my undergraduate project on numerical solutions to the Navier-Stokes equations at the University of Manchester.


# Note

Many of these codes were written abruptly and for one time use only, so it can (and probably will) be hard to read, but (at least most of them) should run smoothly by just executing the cells in the notebooks one after the other.


# Useful links

1. Original materials created by the author of the book that I read Edward J. Hinch to supplement the book (and more) can be found [here](http://www.damtp.cam.ac.uk/user/hinch/teaching/CMIFM_Handouts/).
2. The codes in this repository make heavy use of [SciPy](https://scipy.org/).
